@@ -11,11 +11,8 @@ use strict;
 use warnings;
 
 package Dist::Zilla::App::Command::pot;
-{
-  $Dist::Zilla::App::Command::pot::VERSION = '1.112680';
-}
 # ABSTRACT: update i18n messages.pot file with new strings
-
+$Dist::Zilla::App::Command::pot::VERSION = '1.112681';
 use Dist::Zilla::App -command;
 use File::Temp qw{ tempfile };
 use IO::Prompt;
@@ -33,7 +30,7 @@ sub opt_spec {
     return (
         [],
         [ "output|o=s", "location of the messages.pot to update" ],
-        [ "input|i=s@", "location of the messages.pot to update" ],
+        [ "input|i=s@", "input file(s) (defaults to all .pm files)" ],
     );
 }
 
@@ -50,8 +47,9 @@ sub execute {
         grep { $_->name =~ /\.pm$/ }
         grep { $_->isa( "Dist::Zilla::File::OnDisk" ) }
         $zilla->files->flatten;
-    @pmfiles = grep { $_->_original_name ~~ @{ $opts->{input} } } @pmfiles
-        if $opts->{input};
+
+    @pmfiles = $self->_filter_input_files($opts->{input}, @pmfiles);
+
     my $tmp = File::Temp->new( UNLINK=>1 );
     $tmp->print( map { $_->name . "\n" } @pmfiles );
     $tmp->close;
@@ -90,22 +88,34 @@ sub execute {
     ) == 0 or die "xgettext exited with return code " . ($? >> 8);
 }
 
+sub _filter_input_files {
+  my ($self, $input, @pmfiles) = @_;
+
+  return @pmfiles unless $input && @$input;
+
+  my %filter = map { ($_ => 1) } @$input;
+  return grep { $filter{ $_->_original_name } } @pmfiles;
+}
+
 1;
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Dist::Zilla::App::Command::pot - update i18n messages.pot file with new strings
 
 =head1 VERSION
 
-version 1.112680
+version 1.112681
 
 =head1 SYNOPSIS
 
-    $ dzil pot -p lib/LocaleData/Foo-Bar-messages.pot
+    $ dzil pot -o lib/LocaleData/Foo-Bar-messages.pot
     $ dzil pot
 
 =head1 DESCRIPTION
@@ -153,7 +163,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
